Rayne
=====

.. image:: https://github.com/brobeson/Rayne/actions/workflows/code_quality.yaml/badge.svg
   :target: https://github.com/brobeson/Rayne/actions/workflows/code_quality.yaml

.. image:: https://coveralls.io/repos/github/brobeson/Rayne/badge.svg?branch=main
   :target: https://coveralls.io/github/brobeson/Rayne?branch=main

.. image:: https://img.shields.io/github/license/brobeson/Rayne
   :alt: GitHub License
   :target: https://github.com/brobeson/Rayne?tab=MIT-1-ov-file

.. image:: https://img.shields.io/pypi/v/rayne?logo=python
   :alt: PyPI - Version
   :target: https://pypi.org/project/rayne

.. image:: https://img.shields.io/readthedocs/rayne?logo=readthedocs
   :alt: Read the Docs
   :target: https://rayne.readthedocs.io/en/latest/

Rayne is a micro-benchmarking library for Python code.
It is

#. Easy to use
#. Extensible

Rayne accurately measures your code's execution time by

.. #. Warming up the cache

#. Measuring your code 1000 times
#. Accounting for the time necessary to query your system's clock

So... `get started <https://rayne.readthedocs.io/en/latest/getting_started.html>`_ writing your benchmarks!
